==> diagnosticism-0.3.1.tar.gz: diagnosticism-0.3.1/README.md <==
# diagnosticism.Python
diagnosticism library, for Python

## Table of Contents

1. [Introduction](#introduction)
2. [Installation](#installation)
3. [Components](#components)
4. [Examples](#examples)
5. [Project Information](#project-information)

## Introduction

T.B.C.

## Installation & usage

Install via **pip** or **pip3**, as in:

```
	pip3 install diagnosticism
```

Use via **import**:

```Python

import diagnosticism
```

## Components

**diagnosticism.Python** provides components in the following categories:

* Contingent Reporting
* Diagnostic Logging
* Tracing

**NOTE**: for the moment, the Diagnostic Logging facilities emit to the standard error stream, via the Contingent Reporting API. In the near future this will be changed to work     with more sophisticated logging libraries, including the standard logging facilities and the (as yet to be release) **Pantheios.Python**.

## Examples

Examples are provided in the ```examples``` directory, along with a markdown description for each. A detailed list TOC of them is provided in [EXAMPLES.md](./EXAMPLES.md).

## Project Information

### Where to get help

[GitHub Page](https://github.com/synesissoftware/diagnosticism.Python "GitHub Page")

### Contribution guidelines

Defect reports, feature requests, and pull requests are welcome on https://github.com/synesissoftware/diagnosticism.Python.

### Dependencies

### Related projects

* [**diagnosticism.Go**](https://github.com/synesissoftware/diagnosticism.Go/)
* [**diagnosticism.NET**](https://github.com/synesissoftware/diagnosticism.NET/)

### License

**diagnosticism.Python** is released under the 3-clause BSD license. See [LICENSE](./LICENSE) for details.

==> diagnosticism-0.4.0.tar.gz: diagnosticism-0.4.0/README.md <==
# Diagnosticism.Python
Diagnosticism library, for Python

## Table of Contents

1. [Introduction](#introduction)
2. [Installation](#installation)
3. [Components](#components)
4. [Examples](#examples)
5. [Project Information](#project-information)

## Introduction

T.B.C.

## Installation & usage

Install via **pip** or **pip3**, as in:

```
	pip3 install diagnosticism
```

Use via **import**:

```Python

import diagnosticism
```

## Components

**Diagnosticism.Python** provides components in the following categories:

* Contingent Reporting
* Diagnostic Logging
* Tracing

**NOTE**: for the moment, the Diagnostic Logging facilities emit to the standard error stream, via the Contingent Reporting API. In the near future this will be changed to work     with more sophisticated logging libraries, including the standard logging facilities and the (as yet to be release) **Pantheios.Python**.

## Examples

Examples are provided in the ```examples``` directory, along with a markdown description for each. A detailed list TOC of them is provided in [EXAMPLES.md](./EXAMPLES.md).

## Project Information

### Where to get help

[GitHub Page](https://github.com/synesissoftware/Diagnosticism.Python "GitHub Page")

### Contribution guidelines

Defect reports, feature requests, and pull requests are welcome on https://github.com/synesissoftware/Diagnosticism.Python.

### Dependencies

### Related projects

* [**Diagnosticism.Go**](https://github.com/synesissoftware/Diagnosticism.Go/)
* [**Diagnosticism.NET**](https://github.com/synesissoftware/Diagnosticism.NET/)

### License

**Diagnosticism.Python** is released under the 3-clause BSD license. See [LICENSE](./LICENSE) for details.
